==> knt_ui-1.6.4.tar.gz: lib/src/widget/gallery/knt_gallery_view.dart <==
import 'dart:math' as math;

import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:photo_view/photo_view.dart';
import 'package:photo_view/photo_view_gallery.dart';

import '../../config.dart';
import '../../defined.dart';
import '../../model/models.dart';
import '../image/knt_image.dart';

const _defaultDurationInMillis = Duration(milliseconds: 400);

class KntGalleryView extends StatefulWidget {
  const KntGalleryView({
    Key? key,
    this.photoList = const [],
    this.initIndex,
    this.maxPresentPhoto,
    this.backgroundColor,
    this.closeButton,
  }) : super(key: key);

  final List<Photo> photoList;
  final int? initIndex;
  final int? maxPresentPhoto;
  final Color? backgroundColor;
  final Widget? closeButton;

  @override
  _KntGalleryViewState createState() => _KntGalleryViewState();
}

class _KntGalleryViewState extends State<KntGalleryView> {
  late PageController _pageController;
  late List<Photo> _photoList;
  late int _currentIndex;
  late int _maxPresentPhoto;

  @override
  void initState() {
    super.initState();
    _photoList = [];
    _currentIndex = widget.initIndex ?? 0;
    _maxPresentPhoto =
        widget.maxPresentPhoto ?? DefinedUI.defaultMaxPresentCountGallery;
    _pageController = PageController(initialPage: _currentIndex);
    if (widget.photoList.isNotEmpty) {
      _photoList = widget.photoList
          .sublist(0, math.min(widget.photoList.length, _maxPresentPhoto));
    }
  }

  void _onDismiss(BuildContext context) => Navigator.of(context).pop();

  void _onPageChanged(int index) => setState(() {
        _currentIndex = index;
      });

  void _onPickedPhoto(int index) => _pageController.animateToPage(
        index,
        duration: _defaultDurationInMillis,
        curve: Curves.easeInOut,
      );

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Colors.black,
      child: Stack(
        children: [
          PhotoViewGallery.builder(
            pageController: _pageController,
            scrollPhysics: const BouncingScrollPhysics(),
            backgroundDecoration: BoxDecoration(
              color: widget.backgroundColor ?? Colors.black,
            ),
            onPageChanged: _onPageChanged,
            itemCount: _photoList.length,
            builder: (context, index) {
              final photo = _photoList[index];
              return PhotoViewGalleryPageOptions.customChild(
                child: _ItemPhoto(
                  photo: photo,
                  width: 300.w,
                  height: 300.w,
                ),
                childSize: Size(300.w, 300.w),
                initialScale: PhotoViewComputedScale.contained,
                minScale: PhotoViewComputedScale.contained * (0.5 + index / 10),
                maxScale: PhotoViewComputedScale.covered * 4.1,
                heroAttributes: PhotoViewHeroAttributes(tag: photo.id),
              );
            },
          ),
          Align(
            alignment: Alignment.bottomCenter,
            child: Container(
              height: 36.w + 16.w * 2,
              padding: EdgeInsets.symmetric(vertical: 16.w),
              decoration: BoxDecoration(
                gradient: LinearGradient(
                  colors: [
                    Colors.black54,
                    KntUi.shared.secondaryColor.withAlpha(25),
                  ],
                  begin: Alignment.bottomCenter,
                  end: Alignment.topCenter,
                ),
              ),
              alignment: Alignment.center,
              child: ListView.builder(
                physics: const BouncingScrollPhysics(),
                scrollDirection: Axis.horizontal,
                padding: EdgeInsets.symmetric(horizontal: 16.w),
                itemBuilder: (context, index) {
                  final photo = _photoList[index];
                  return InkWell(
                    onTap: () => _onPickedPhoto(index),
                    child: _ItemPhoto(
                      photo: photo,
                      asCover: false,
                      needBorder: _currentIndex == index,
                    ),
                  );
                },
                itemCount: _photoList.length,
              ),
            ),
          ),
          Positioned(
            top: 48.w - 4.w,
            right: 10.w,
            child: widget.closeButton ??
                InkWell(
                  onTap: () => _onDismiss(context),
                  child: Container(
                    width: 24.w + 20.w,
                    height: 36.w,
                    child: Icon(
                      Icons.close,
                      color: Colors.white,
                      size: 24.w,
                    ),
                  ),
                ),
          ),
        ],
      ),
    );
  }
}

class _ItemPhoto extends StatelessWidget {
  final Photo photo;
  final bool asCover;
  final double? width;
  final double? height;
  final bool needBorder;

  const _ItemPhoto({
    Key? key,
    required this.photo,
    this.asCover = true,
    this.width,
    this.height,
    this.needBorder = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final nonNullWidth = width ?? 56.w;
    final nonNullHeight = height ?? 36.w;
    final uri = asCover ? photo.coverUri : photo.thumbnailUri;
    return Container(
      width: nonNullWidth,
      height: nonNullHeight,
      decoration: BoxDecoration(
        border: Border.all(
          width: 3.w,
          color: needBorder
              ? KntUi.shared.primaryColor.withAlpha(124)
              : Colors.transparent,
        ),
      ),
      child: KntImage(
        uri: uri,
        width: nonNullWidth,
        height: nonNullHeight,
        imageType: photo.storageType,
      ),
    );
  }
}

==> knt_ui-1.6.7.tar.gz: lib/src/widget/gallery/knt_gallery_view.dart <==
import 'dart:math' as math;

import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:photo_view/photo_view.dart';
import 'package:photo_view/photo_view_gallery.dart';

import '../../config.dart';
import '../../defined.dart';
import '../../model/models.dart';
import '../image/knt_image.dart';

const _defaultDurationInMillis = Duration(milliseconds: 400);

class KntGalleryView extends StatefulWidget {
  const KntGalleryView({
    Key? key,
    this.photoList = const [],
    this.initIndex,
    this.maxPresentPhoto,
    this.backgroundColor,
    this.closeButton,
  }) : super(key: key);

  final List<Photo> photoList;
  final int? initIndex;
  final int? maxPresentPhoto;
  final Color? backgroundColor;
  final Widget? closeButton;

  @override
  _KntGalleryViewState createState() => _KntGalleryViewState();
}

class _KntGalleryViewState extends State<KntGalleryView> {
  late PageController _pageController;
  late List<Photo> _photoList;
  late int _currentIndex;
  late int _maxPresentPhoto;

  @override
  void initState() {
    super.initState();
    _photoList = [];
    _currentIndex = widget.initIndex ?? 0;
    _maxPresentPhoto =
        widget.maxPresentPhoto ?? DefinedUI.defaultMaxPresentCountGallery;
    _pageController = PageController(initialPage: _currentIndex);
    if (widget.photoList.isNotEmpty) {
      _photoList = widget.photoList
          .sublist(0, math.min(widget.photoList.length, _maxPresentPhoto));
    }
  }

  void _onDismiss(BuildContext context) => Navigator.of(context).pop();

  void _onPageChanged(int index) => setState(() {
        _currentIndex = index;
      });

  void _onPickedPhoto(int index) => _pageController.animateToPage(
        index,
        duration: _defaultDurationInMillis,
        curve: Curves.easeInOut,
      );

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Colors.black,
      child: Stack(
        children: [
          PhotoViewGallery.builder(
            pageController: _pageController,
            scrollPhysics: const BouncingScrollPhysics(),
            backgroundDecoration: BoxDecoration(
              color: widget.backgroundColor ?? Colors.black,
            ),
            onPageChanged: _onPageChanged,
            itemCount: _photoList.length,
            builder: (context, index) {
              final photo = _photoList[index];
              return PhotoViewGalleryPageOptions.customChild(
                child: _ItemPhoto(
                  photo: photo,
                  width: 300.w,
                  height: 300.w,
                ),
                childSize: Size(300.w, 300.w),
                initialScale: PhotoViewComputedScale.contained,
                minScale: PhotoViewComputedScale.contained * 0.5,
                maxScale: PhotoViewComputedScale.covered * 4.1,
                heroAttributes: PhotoViewHeroAttributes(tag: photo.id),
              );
            },
          ),
          Align(
            alignment: Alignment.bottomCenter,
            child: Container(
              height: 36.w + 16.w * 2,
              padding: EdgeInsets.symmetric(vertical: 16.w),
              decoration: BoxDecoration(
                gradient: LinearGradient(
                  colors: [
                    Colors.black54,
                    KntUi.shared.secondaryColor.withAlpha(25),
                  ],
                  begin: Alignment.bottomCenter,
                  end: Alignment.topCenter,
                ),
              ),
              alignment: Alignment.center,
              child: ListView.builder(
                physics: const BouncingScrollPhysics(),
                scrollDirection: Axis.horizontal,
                padding: EdgeInsets.symmetric(horizontal: 16.w),
                itemBuilder: (context, index) {
                  final photo = _photoList[index];
                  return InkWell(
                    onTap: () => _onPickedPhoto(index),
                    child: _ItemPhoto(
                      photo: photo,
                      asCover: false,
                      needBorder: _currentIndex == index,
                    ),
                  );
                },
                itemCount: _photoList.length,
              ),
            ),
          ),
          Positioned(
            top: 48.w - 4.w,
            right: 10.w,
            child: widget.closeButton ??
                InkWell(
                  onTap: () => _onDismiss(context),
                  child: Container(
                    width: 24.w + 20.w,
                    height: 36.w,
                    child: Icon(
                      Icons.close,
                      color: Colors.white,
                      size: 24.w,
                    ),
                  ),
                ),
          ),
        ],
      ),
    );
  }
}

class _ItemPhoto extends StatelessWidget {
  final Photo photo;
  final bool asCover;
  final double? width;
  final double? height;
  final bool needBorder;

  const _ItemPhoto({
    Key? key,
    required this.photo,
    this.asCover = true,
    this.width,
    this.height,
    this.needBorder = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final nonNullWidth = width ?? 56.w;
    final nonNullHeight = height ?? 36.w;
    final uri = asCover ? photo.coverUri : photo.thumbnailUri;
    return Container(
      width: nonNullWidth,
      height: nonNullHeight,
      decoration: BoxDecoration(
        border: Border.all(
          width: 3.w,
          color: needBorder
              ? KntUi.shared.primaryColor.withAlpha(124)
              : Colors.transparent,
        ),
      ),
      child: KntImage(
        uri: uri,
        width: nonNullWidth,
        height: nonNullHeight,
        imageType: photo.storageType,
      ),
    );
  }
}
